@@ -11,6 +11,8 @@ from typing import Optional, Dict
 from torch import nn, Tensor
 from zcls2.config.key_word import KEY_OUTPUT
 
+__all__ = ['CrossEntropyLoss', 'cross_entropy_loss']
+
 
 class CrossEntropyLoss(nn.CrossEntropyLoss):
 
@@ -24,5 +26,4 @@ class CrossEntropyLoss(nn.CrossEntropyLoss):
         return super().forward(inputs, target)
 
 
-def build_cross_entropy_loss(reduction: str = 'mean', label_smoothing=0.0) -> nn.Module:
-    return CrossEntropyLoss(reduction=reduction, label_smoothing=label_smoothing)
+cross_entropy_loss = CrossEntropyLoss
